@@ -98,7 +98,7 @@ const char *http_fn_aut		= "Authorization:";
 const char *http_fn_auw		= "WWW-Authenticate:";
 const char *http_fn_ran		= "Range:";
 const char *http_fn_rac		= "Content-Range:";
-const char *http_fv_srv		= "Nostromo/1.7.3 (Unix)";
+const char *http_fv_srv		= "Nostromo/1.7.4 (Unix)";
 const char *http_fv_pro		= "HTTP/1.1";
 const char *http_fv_cgi		= "CGI/1.1";
 const char *http_fv_teg		= "chunked";
@@ -109,6 +109,8 @@ const char *http_fv_con_cls	= "close";
 char	http_fv_alv[128];
 char	http_fv_cte[128];
 char	http_url[128];
+char	http_sig[128];
+char	http_path[128];
 
 struct cfg		config;
 struct connection	c[CON];
@@ -289,9 +291,9 @@ main(int argc, char *argv[])
 	int			sdmax, sdnew, sdnow;
 	int			i, j, k, r, s, ch, rd, rp, rt, wr, post, size;
 	int			fd, erro, mode, opt_c, opt_r, opt_4, opt_6;
-	char			in[HDN * HDS + 1], tmp[HDS + 1], body[HDS + 1];
+	char			in[HDN * HDS + 1], tmp[HDS + 1];
 	char			header[HDN][HDS + 1];
-	char			*b, *h;
+	char			*b, *h, *body = NULL;
 	extern char		**environ;
 	struct passwd		*pwd = NULL;
 	struct stat		st;
@@ -510,18 +512,10 @@ main(int argc, char *argv[])
 	sys_mime(http_fv_cte, sizeof(http_fv_cte), mimes, mimes_size, "html");
 
 	/*
-	 * Set environment variables
+	 * Clear all environment variables and save PATH
 	 */
-	/* clear all environment variables except PATH */
-	strlcpy(tmp, getenv("PATH"), sizeof(tmp));
+	strlcpy(http_path, getenv("PATH"), sizeof(http_path));
 	memset(environ, 0, sizeof(environ));
-	/* set static environment variables */
-	setenv("PATH", tmp, 1);
-	setenv("GATEWAY_INTERFACE", http_fv_cgi, 1);
-	setenv("SERVER_ADMIN", config.serveradmin, 1);
-	setenv("SERVER_NAME", config.servername, 1);
-	setenv("SERVER_PROTOCOL", http_fv_pro, 1);
-	setenv("SERVER_SOFTWARE", http_fv_srv, 1);
 
 	/*
 	 * Get servers IP adress(es)
@@ -1005,7 +999,6 @@ main(int argc, char *argv[])
 			 * Active connection sends request
 			 */
 			memset(tmp, 0, sizeof(tmp));
-			memset(body, 0, sizeof(body));
 
 			/* receive data */
 			if (c[sdnow].x_ssl)
@@ -1098,8 +1091,7 @@ main(int argc, char *argv[])
 					free(b);
 					goto quit;
 				}
-				if (in[i] == '\n' && in[i + 2] == '\n' && post
-				    < 2) {
+				if (in[i] == '\n' && in[i + 2] == '\n') {
 					tmp[j] = in[i];
 					i = i + 2;
 					strlcpy(header[k], tmp,
@@ -1107,63 +1099,19 @@ main(int argc, char *argv[])
 					k++;
 					j = 0;
 					memset(tmp, 0, sizeof(tmp));
-					if (post == 1)
-						post = 2;
 				} else {
 					tmp[j] = in[i];
 					j++;
 				}
+				/* we got the post header */
+				if (post == 1 && k == 1)
+					break;
 			}
 
-			/* for post receive body entity */
+			/* for post get initial body content */
 			if (post) {
-				rt = j;
-				memcpy(body, tmp, rt);
-				memset(tmp, 0, sizeof(tmp));
-				FD_ZERO(&seto_r);
-				FD_SET(sdnow, &seto_r);
-				while((size = http_body_comp(header[0], body,
-				    rt)) == 0) {
-					tv.tv_sec = 1;
-					tv.tv_usec = 0;
-					r = select(sdnow + 1, &seto_r, NULL,
-					    NULL, &tv);
-					if (r == -1) {
-						if (errno == EINTR)
-							continue;
-						goto quit;
-					}
-					if (r == 0)
-						goto quit;
-					/* size check for body */
-					if (rt == sizeof(body) - 1) {
-						h = http_head(http_s_413, "-",
-						    c[sdnow].ip);
-						b = http_body(http_s_413,"", h);
-						if (c[sdnow].x_ssl) {
-							SSL_write(c[sdnow].ssl,
-							    b, strlen(b));
-						} else {
-							sys_write(sdnow, b,
-							    strlen(b));
-						}
-						free(h);
-						free(b);
-						goto quit;
-					}
-					if (c[sdnow].x_ssl) {
-						rp = SSL_read(c[sdnow].ssl,
-						    body + rt,
-						    (sizeof(body) - rt) - 1);
-					} else {
-						rp = sys_read(sdnow,
-						    body + rt,
-						    (sizeof(body) - rt) - 1);
-					}
-					if (rp < 1)
-						goto quit;
-					rt += rp;
-				}
+				body = in + (strlen(header[0]) + 2);
+				size = rt - (strlen(header[0]) + 2);
 			}
 
 			/* and process every single header */
