@@ -237,35 +237,49 @@ sys_close_except(const int fd)
  *	pointer to date string = sucessfull, NULL = error
  */
 char *
-sys_date(struct tm *t, int gmt)
+sys_date(struct tm *t)
 {
-	int		hour, min, sec, year, mon, mday, diff;
+	int		diff;
 	char		*d, sign;
 	static char	date[64];
 
-	hour = t->tm_hour;
-	min = t->tm_min;
-	sec = t->tm_sec;
-	year = t->tm_year;
-	mon = t->tm_mon;
-	mday = t->tm_mday;
-
-	if (hour == 0)
-		diff = 24 - gmt;
-	else
-		diff = hour - gmt;
+	diff = t->tm_gmtoff / 3600;
 
 	if (diff < 0) {
-		diff = abs(diff);
+		diff = -diff;
 		sign = '-';
 	} else {
 		sign = '+';
 	}
 
 	snprintf(date, sizeof(date), "[%02d/%s/%d:%02d:%02d:%02d %c%02d00]",
-	    mday, month[mon], year + 1900, hour, min, sec, sign, diff);
+	    t->tm_mday, month[t->tm_mon], t->tm_year + 1900, t->tm_hour,
+	    t->tm_min, t->tm_sec, sign, diff);
 
 	d = date;
 
 	return d;
 }
+
+/*
+ * sys_benv()
+ *	build an environment string and return its address so we can pass it
+ *	to an environment pointer array
+ * Return:
+ *	pointer to environment string = successfull, NULL = error
+ */
+char *
+sys_benv(const char *str, ...)
+{
+	char	buf[1024];
+	char	*p;
+	va_list	ap;
+
+	va_start(ap, str);
+	vsnprintf(buf, sizeof(buf), str, ap);
+	va_end(ap);
+
+	p = strdup(buf);
+
+	return p;
+}
